@@ -1,34 +1,46 @@
 # Helper infrastructure for remctl backend programs.
 #
-# SPDX-License-Identifier: MIT
+# Written by Russ Allbery <rra@stanford.edu>
+# Copyright 2012, 2013
+#     The Board of Trustees of the Leland Stanford Junior University
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to
+# deal in the Software without restriction, including without limitation the
+# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+# sell copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+# IN THE SOFTWARE.
 
 package Net::Remctl::Backend;
 
-use 5.010;
+use 5.006;
 use strict;
 use warnings;
 
 use Getopt::Long;
 use Text::Wrap qw(wrap);
 
-# Line width for formatting.  Avoid dependency on Readonly.
+# Tab and line width for formatting.  Avoid dependency on Readonly.
+use constant TAB_WIDTH  => 8;
 use constant LINE_WIDTH => 80;
 
-# In the help output, command syntax longer than this will shift the summary
-# to the following line and will not affect the column in which the summary
-# starts.
-use constant MAX_SYNTAX_LENGTH => 48;
-
-# If all syntax lines exceed MAX_SYNTAX_LENGTH, start the summary output in
-# this column.
-use constant DEFAULT_SUMMARY_COLUMN => 40;
-
 our $VERSION;
 
 # This version matches the version of remctl with which this module was
 # released, but with at least two digits for the minor version.
 BEGIN {
-    $VERSION = '3.18';
+    $VERSION = '3.05';
 }
 
 # Constructor.  Takes all possible parameters as a hash.  See the POD
@@ -78,7 +90,7 @@ sub _build_help {
         # Get the syntax and summary for this command and add it to the
         # arrays if there is any syntax defined.  Avoid trailing whitespace
         # if there is no extra syntax.
-        my $syntax = $config->{syntax};
+        my $syntax  = $config->{syntax};
         my $summary = $config->{summary};
         if (defined($syntax)) {
             if (length($syntax) > 0) {
@@ -115,7 +127,18 @@ sub help {
     # Generate two parallel lists of syntax and summaries.
     my ($syntax_ref, $summary_ref) = $self->_build_help($self->{commands});
 
-    # Calculate the prefix that will be added to each line of the syntax.
+    # Calculate the maximum syntax length.  Add in the length of the command.
+    my $max_syntax_len = 0;
+    for my $syntax (@{$syntax_ref}) {
+        if (length($syntax) > $max_syntax_len) {
+            $max_syntax_len = length($syntax);
+        }
+    }
+
+    # Padding is constructed as follows: add two to the maximum length to
+    # account for two blank spaces at the start of the line if there is a
+    # help_prefix set.  Add the length of the command and a space if command
+    # is set.  Then pad to two blanck spaces after the longest syntax block.
     my $prefix = q{};
     if ($self->{help_banner}) {
         $prefix = q{ } x 2;
@@ -123,27 +146,7 @@ sub help {
     if ($self->{command}) {
         $prefix .= $self->{command} . q{ };
     }
-
-    # Calculate the longest syntax length, except for very long lines that
-    # pass the MAX_SYNTAX cutoff.
-    my $longest_syntax_len = 0;
-    my $max_syntax_len = MAX_SYNTAX_LENGTH - length($prefix);
-    for my $syntax (@{$syntax_ref}) {
-        my $length = length($syntax);
-        if ($length > $longest_syntax_len && $length <= $max_syntax_len) {
-            $longest_syntax_len = $length;
-        }
-    }
-
-    # The summary starts two blank spaces after the longest syntax block that
-    # does not exceed the length cap.  If all the syntax lines are too long,
-    # arbitrarily start in column 40.
-    my $pad_column;
-    if ($longest_syntax_len > 0) {
-        $pad_column = length($prefix) + $longest_syntax_len + 2;
-    } else {
-        $pad_column = DEFAULT_SUMMARY_COLUMN;
-    }
+    my $pad_column = $max_syntax_len + 2 + length($prefix);
 
     # Add the help banner if one is set.  Add a newline if there isn't one.
     my $output = q{};
@@ -155,10 +158,10 @@ sub help {
     }
 
     # Now, we can format each line of the help output with Text::Wrap.
-    local $Text::Wrap::columns = LINE_WIDTH;
+    local $Text::Wrap::columns  = LINE_WIDTH;
     local $Text::Wrap::unexpand = 0;
     for my $i (0 .. $#{$syntax_ref}) {
-        my $syntax = $syntax_ref->[$i];
+        my $syntax  = $syntax_ref->[$i];
         my $summary = $summary_ref->[$i];
 
         # If there is no summary, just add the bare command syntax.
@@ -167,19 +170,11 @@ sub help {
             next;
         }
 
-        # Otherwise, line up the columns and wrap the summary.  If the length
-        # goes beyond the pad column minus two (for the blank spaces), move
-        # the summary to the next line.
+        # Otherwise, line up the columns and wrap the summary.
         my $length = length($prefix) + length($syntax);
-        if ($length <= $pad_column - 2) {
-            my $padding = q{ } x ($pad_column - $length);
-            $syntax = $prefix . $syntax . $padding;
-            $output .= wrap($syntax, q{ } x $pad_column, $summary . "\n");
-        } else {
-            my $padding = q{ } x $pad_column;
-            $output .= $prefix . $syntax . "\n";
-            $output .= wrap($padding, $padding, $summary . "\n");
-        }
+        my $padding = q{ } x ($pad_column - $length);
+        $syntax = $prefix . $syntax . $padding;
+        $output .= wrap($syntax, q{ } x $pad_column, $summary . "\n");
     }
 
     # Return the formatted results.
@@ -264,7 +259,7 @@ sub _check_args_regex {
 
     # Loop through thte arguments and check against the corresponding regex.
     for my $i (0 .. $#{$args_ref}) {
-        my $arg = $args_ref->[$i];
+        my $arg   = $args_ref->[$i];
         my $regex = $regexes_ref->[$i];
         if (defined($regex) && $arg !~ $regex) {
             if ($arg =~ m{ [^[:print:]] }xms) {
@@ -360,7 +355,6 @@ sub run {
     # If configured to read data from standard input, do so, and splice that
     # into the argument list.  Save the index of the stdin argument for later
     # since the error message for invalid arguments changes.
-    ## no critic (InputOutput::ProhibitExplicitStdin)
     my $stdin_index;
     my $args_count = scalar(@{$args_ref});
     if (defined($config->{stdin})) {
@@ -370,9 +364,7 @@ sub run {
             $stdin_index = $args_count + 1;
         }
         splice(@{$args_ref}, $stdin_index - 1, 0, $stdin);
-        $args_count = scalar(@{$args_ref});
     }
-    ## use critic
 
     # Check the number of arguments if desired.
     if (defined($config->{args_max}) && $config->{args_max} < $args_count) {
@@ -399,8 +391,6 @@ sub run {
 
 1;
 
-__END__
-
 =for stopwords
 remctl remctld backend subcommand subcommands Allbery MERCHANTABILITY
 NONINFRINGEMENT sublicense STDERR STDOUT regex regexes CONFIG undef
@@ -566,17 +556,6 @@ Checks for the number of arguments and for the validity of arguments with
 regular expression verification are done after reading the data from
 standard input and transforming the argument list accordingly.
 
-=item summary
-
-The summary of what this subcommand does, as text.  Ideally, this should
-fit on the same line with the syntax after the help output has been laid
-out in columns.  If it is too long to fit, it will be wrapped, with each
-subsequent line indented to the column where the summaries start.
-
-If this key is omitted, the subcommand will still be shown in help
-output, provided that it has a syntax key, but without any trailing
-summary.
-
 =item syntax
 
 The syntax of this subcommand.  This should be short, since it needs to
@@ -601,6 +580,17 @@ no arguments or flags.
 
 If this key is omitted, the subcommand will be omitted from help output.
 
+=item summary
+
+The summary of what this subcommand does, as text.  Ideally, this should
+fit on the same line with the syntax after the help output has been laid
+out in columns.  If it is too long to fit, it will be wrapped, with each
+subsequent line indented to the column where the summaries start.
+
+If this key is omitted, the subcommand will still be shown in help
+output, provided that it has a syntax key, but without any trailing
+summary.
+
 =back
 
 =back
@@ -664,30 +654,25 @@ user passed in more arguments than that.
 
 =back
 
-=head1 COMPATIBILITY
-
-This module was added in the 3.4 release of remctl.  Since 3.5, the module
-version matches the remctl version but with a leading zero added so that
-the minor version always has two numbers (so Net::Remctl::Backend 3.05 was
-included in remctl 3.5).
-
-All currently-supported methods and options have been supported since the
-original release of the module.
-
 =head1 BUGS
 
 There is no way to check all arguments with a regex when the command
 supports any number of arguments.
 
+=head1 SEE ALSO
+
+remctld(8)
+
+The current version of this module is available from its web page at
+L<http://www.eyrie.org/~eagle/software/remctl/>.
+
 =head1 AUTHOR
 
-Russ Allbery <eagle@eyrie.org>
+Russ Allbery <rra@stanford.edu>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2019-2020, 2022 Russ Allbery <eagle@eyrie.org>
-
-Copyright 2012-2014 The Board of Trustees of the Leland Stanford Junior
+Copyright 2012, 2013 The Board of Trustees of the Leland Stanford Junior
 University
 
 Permission is hereby granted, free of charge, to any person obtaining a
@@ -708,15 +693,4 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 
-=head1 SEE ALSO
-
-remctld(8)
-
-The current version of this module is available from its web page at
-L<https://www.eyrie.org/~eagle/software/remctl/>.
-
 =cut
-
-# Local Variables:
-# copyright-at-end-flag: t
-# End:
