@@ -5,7 +5,7 @@
  * which can be found at <http://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <rra@stanford.edu>
- * Copyright 2005 Russ Allbery <rra@stanford.edu>
+ * Copyright 2005, 2013 Russ Allbery <rra@stanford.edu>
  * Copyright 2009, 2010, 2011, 2012
  *     The Board of Trustees of the Leland Stanford Junior University
  *
@@ -245,7 +245,7 @@ test_all(const char *source_ipv4, const char *source_ipv6 UNUSED)
     socket_type *fds, fd;
     unsigned int count, i;
     pid_t child;
-    struct sockaddr_storage saddr;
+    struct sockaddr *saddr;
     socklen_t size;
     int status;
 
@@ -263,18 +263,25 @@ test_all(const char *source_ipv4, const char *source_ipv6 UNUSED)
             ok_block(4, 0, "all address server test (part %d)", i);
         } else {
             ok(1, "all address server test (part %d)", i);
-            size = sizeof(saddr);
-            if (getsockname(fd, (struct sockaddr *) &saddr, &size) < 0)
+            saddr = bmalloc(sizeof(struct sockaddr));
+            size = sizeof(struct sockaddr);
+            if (getsockname(fd, saddr, &size) < 0)
                 sysbail("cannot getsockname");
+            if (size > sizeof(struct sockaddr)) {
+                free(saddr);
+                saddr = bmalloc(size);
+                if (getsockname(fd, saddr, &size) < 0)
+                    sysbail("cannot getsockname");
+            }
             child = fork();
             if (child < 0)
                 sysbail("cannot fork");
             else if (child == 0) {
-                if (saddr.ss_family == AF_INET) {
+                if (saddr->sa_family == AF_INET) {
                     client("::1", source_ipv6, false);
                     client("127.0.0.1", source_ipv4, true);
 #ifdef HAVE_INET6
-                } else if (saddr.ss_family == AF_INET6) {
+                } else if (saddr->sa_family == AF_INET6) {
 # ifdef IPV6_V6ONLY
                     client("127.0.0.1", source_ipv4, false);
 # endif
@@ -283,6 +290,7 @@ test_all(const char *source_ipv4, const char *source_ipv6 UNUSED)
                 }
                 _exit(1);
             } else {
+                free(saddr);
                 listener(fd);
                 waitpid(child, &status, 0);
                 is_int(0, status, "client made correct connections");
@@ -400,11 +408,8 @@ test_timeout_ipv4(void)
     if (child < 0)
         sysbail("cannot fork");
     else if (child == 0) {
-        struct sockaddr_in sin;
-        socklen_t slen;
-
         alarm(10);
-        c = accept(fd, &sin, &slen);
+        c = accept(fd, NULL, 0);
         if (c == INVALID_SOCKET)
             _exit(1);
         sleep(9);
@@ -568,8 +573,8 @@ test_network_write(void)
     socklen_t slen;
     char *buffer;
 
-    buffer = bmalloc(512 * 1024);
-    memset(buffer, 'a', 512 * 1024);
+    buffer = bmalloc(4096 * 1024);
+    memset(buffer, 'a', 4096 * 1024);
     fd = network_bind_ipv4("127.0.0.1", 11119);
     if (fd == INVALID_SOCKET)
         sysbail("cannot create or bind socket");
@@ -577,6 +582,7 @@ test_network_write(void)
         sysdiag("cannot listen to socket");
         ok_block(4, 0, "network_write");
         socket_close(fd);
+        free(buffer);
         return;
     }
     child = fork();
@@ -596,13 +602,14 @@ test_network_write(void)
             sysdiag("cannot accept on socket");
             ok_block(4, 0, "network_write");
             socket_close(fd);
+            free(buffer);
             return;
         }
         socket_set_errno(0);
         ok(network_write(c, buffer, 32 * 1024, 0), "network_write");
         ok(network_write(c, buffer, 32 * 1024, 1),
            "network_write with timeout");
-        ok(!network_write(c, buffer, 512 * 1024, 1),
+        ok(!network_write(c, buffer, 4096 * 1024, 1),
            "network_write aborted with timeout");
         is_int(ETIMEDOUT, socket_errno, "...with correct error");
         socket_close(c);
@@ -611,6 +618,7 @@ test_network_write(void)
         alarm(0);
     }
     socket_close(fd);
+    free(buffer);
 }
 
 
